# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common new_handlers new_service set_config
NULL

#' AWS License Manager User Subscriptions
#'
#' @description
#' With License Manager, you can create user-based subscriptions to utilize
#' licensed software with a per user subscription fee on Amazon EC2
#' instances.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{access_key_id}:} {AWS access key ID}
#' \item{\strong{secret_access_key}:} {AWS secret access key}
#' \item{\strong{session_token}:} {AWS temporary session token}
#' \item{\strong{profile}:} {The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}:} {Set anonymous credentials.}
#' \item{\strong{endpoint}:} {The complete URL to use for the constructed client.}
#' \item{\strong{region}:} {The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}:} {Immediately close all HTTP connections.}
#' \item{\strong{timeout}:} {The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}:} {Set this to `true` to force the request to use path-style addressing, i.e., `http://s3.amazonaws.com/BUCKET/KEY`.}
#' }
#'
#' @section Service syntax:
#' ```
#' svc <- licensemanagerusersubscriptions(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical"
#'   )
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- licensemanagerusersubscriptions()
#' svc$associate_user(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[=licensemanagerusersubscriptions_associate_user]{associate_user} \tab Associates the user to an EC2 instance to utilize user-based subscriptions\cr
#'  \link[=licensemanagerusersubscriptions_deregister_identity_provider]{deregister_identity_provider} \tab Deregisters the identity provider from providing user-based subscriptions\cr
#'  \link[=licensemanagerusersubscriptions_disassociate_user]{disassociate_user} \tab Disassociates the user from an EC2 instance providing user-based subscriptions\cr
#'  \link[=licensemanagerusersubscriptions_list_identity_providers]{list_identity_providers} \tab Lists the identity providers for user-based subscriptions\cr
#'  \link[=licensemanagerusersubscriptions_list_instances]{list_instances} \tab Lists the EC2 instances providing user-based subscriptions\cr
#'  \link[=licensemanagerusersubscriptions_list_product_subscriptions]{list_product_subscriptions} \tab Lists the user-based subscription products available from an identity provider\cr
#'  \link[=licensemanagerusersubscriptions_list_user_associations]{list_user_associations} \tab Lists user associations for an identity provider\cr
#'  \link[=licensemanagerusersubscriptions_register_identity_provider]{register_identity_provider} \tab Registers an identity provider for user-based subscriptions\cr
#'  \link[=licensemanagerusersubscriptions_start_product_subscription]{start_product_subscription} \tab Starts a product subscription for a user with the specified identity provider\cr
#'  \link[=licensemanagerusersubscriptions_stop_product_subscription]{stop_product_subscription} \tab Stops a product subscription for a user with the specified identity provider\cr
#'  \link[=licensemanagerusersubscriptions_update_identity_provider_settings]{update_identity_provider_settings} \tab Updates additional product configuration settings for the registered identity provider
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname licensemanagerusersubscriptions
#' @export
licensemanagerusersubscriptions <- function(config = list()) {
  svc <- .licensemanagerusersubscriptions$operations
  svc <- set_config(svc, config)
  return(svc)
}

# Private API objects: metadata, handlers, interfaces, etc.
.licensemanagerusersubscriptions <- list()

.licensemanagerusersubscriptions$operations <- list()

.licensemanagerusersubscriptions$metadata <- list(
  service_name = "licensemanagerusersubscriptions",
  endpoints = list("*" = list(endpoint = "license-manager-user-subscriptions.{region}.amazonaws.com", global = FALSE), "cn-*" = list(endpoint = "license-manager-user-subscriptions.{region}.amazonaws.com.cn", global = FALSE), "us-iso-*" = list(endpoint = "license-manager-user-subscriptions.{region}.c2s.ic.gov", global = FALSE), "us-isob-*" = list(endpoint = "license-manager-user-subscriptions.{region}.sc2s.sgov.gov", global = FALSE)),
  service_id = "License Manager User Subscriptions",
  api_version = "2018-05-10",
  signing_name = "license-manager-user-subscriptions",
  json_version = "1.1",
  target_prefix = ""
)

.licensemanagerusersubscriptions$service <- function(config = list()) {
  handlers <- new_handlers("restjson", "v4")
  new_service(.licensemanagerusersubscriptions$metadata, handlers, config)
}
